@@ -7,7 +7,7 @@ from pathlib import Path
 from functools import wraps
 
 from einops import rearrange
-from memorizing_transformers_pytorch.utils import rearrange_with_dim_list
+from einops_exts import rearrange_with_anon_dims
 
 # constants
 
@@ -198,8 +198,8 @@ class KNNMemory():
         all_key_values = torch.stack(all_key_values)
         all_key_values = all_key_values.masked_fill(~rearrange(all_masks, '... -> ... 1 1'), 0.)
 
-        all_key_values = rearrange_with_dim_list(all_key_values, 'b (...p) ... -> b ...p ...', p = prec_dims)
-        all_masks = rearrange_with_dim_list(all_masks, 'b (...p) ... -> b ...p ...', p = prec_dims)
+        all_key_values = rearrange_with_anon_dims(all_key_values, 'b (...p) ... -> b ...p ...', p = prec_dims)
+        all_masks = rearrange_with_anon_dims(all_masks, 'b (...p) ... -> b ...p ...', p = prec_dims)
 
         return all_key_values.to(device), all_masks.to(device)
 
